@@ -2,19 +2,14 @@ import os
 import logging
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
 from django.template.loader import render_to_string
-from django.utils import simplejson as json
 from django.utils.translation import ugettext as _
 
-from lizard_map.models import DEFAULT_WORKSPACES
+from lizard_map.adapter import adapter_serialize
 from lizard_map.models import ICON_ORIGINALS
-from lizard_map.models import OTHER_WORKSPACES
-from lizard_map.models import TEMP_WORKSPACES
-from lizard_map.models import USER_WORKSPACES
 from lizard_map.models import Color
 from lizard_map.models import Legend
-from lizard_map.models import Workspace
+#from lizard_map.models import Workspace
 from lizard_map.symbol_manager import SymbolManager
 
 logger = logging.getLogger('lizard_map.workspace')
@@ -32,133 +27,6 @@ COLORS_DEFAULT = [
     ]
 
 
-class WorkspaceManager:
-
-    def __init__(self, request):
-        self.request = request
-        self.workspaces = {}
-
-    def save_workspaces(self):
-        """save workspaces to session"""
-        workspace_group_ids = {}
-        for group, workspace_list in self.workspaces.items():
-            workspace_group_ids[group] = [workspace.id for workspace in
-                                          workspace_list]
-        self.request.session['workspaces'] = workspace_group_ids
-        logger.debug('WorkspaceManager.save_workspaces: saved '
-                     'workspace_group_ids in session.')
-
-    def load_workspaces(self, workspace_group_ids=None):
-        """load workspaces from session
-
-        note: request.session['workspaces'] must be filled before
-        using this function
-
-        returns number of workspaces that could not be loaded"""
-        errors = 0
-        if workspace_group_ids is None:
-            if 'workspaces' in self.request.session:
-                workspace_group_ids = self.request.session['workspaces']
-            else:
-                logger.warn(('WorkspaceManager.load_workspaces: no workspaces'
-                             ' in kwargs or in session.'))
-                return 1
-        # Workspaces are grouped by key TEMP_WORKSPACES, USER_WORKSPACES, etc.
-        for group, workspace_ids in workspace_group_ids.items():
-            self.workspaces[group] = []
-            for workspace_id in workspace_ids:
-                try:
-                    new_workspace = Workspace.objects.get(pk=workspace_id)
-                    self.workspaces[group].append(new_workspace)
-                except Workspace.DoesNotExist:
-                    errors += 1
-        return errors
-
-    def empty(self, category=TEMP_WORKSPACES):
-        #clear all items in workspace category
-        for workspace in self.workspaces[category]:
-            workspace.workspace_items.all().delete()
-
-    def load_or_create(self, new_workspace=False):
-        """load workspaces references by session['workspaces'] or
-        create new workspace (saves in case of changes to workspaces)
-
-        workspaces are returned in a dictionary:
-        {
-        'default': [...default layers],
-        'temp': workspace_temp,
-        'user': [...user workspaces]
-        }
-
-        they are stored in the session as a dictionary of ids:
-        {
-        'default': [id1, id2, ...],
-        'temp': [id, ],
-        'user': [id3, id4, ...],
-        }
-        """
-
-        self.workspaces = {}
-        changes = False
-        if 'workspaces' in self.request.session:
-            changes = self.load_workspaces()
-
-        #check if components exist, else create them
-        if not DEFAULT_WORKSPACES in self.workspaces:
-            try:
-                self.workspaces[DEFAULT_WORKSPACES] = [
-                    Workspace.objects.get(name='achtergrond')]
-                # ^^^ TODO: use non-Dutch name.
-            except Workspace.DoesNotExist:
-                pass
-            changes = True
-
-        if (not TEMP_WORKSPACES in self.workspaces or
-            not self.workspaces[TEMP_WORKSPACES]):
-            workspace_temp = Workspace(name=TEMP_WORKSPACES)
-            workspace_temp.save()
-            self.workspaces[TEMP_WORKSPACES] = [workspace_temp]
-            changes = True
-
-        if (new_workspace or
-            not USER_WORKSPACES in self.workspaces or
-            not len(self.workspaces[USER_WORKSPACES])):
-            workspace_user = Workspace()
-            workspace_user.save()
-            self.workspaces[USER_WORKSPACES] = [workspace_user]
-            changes = True
-
-        #create collage if necessary, it is stored in the workspace
-        if self.workspaces[USER_WORKSPACES][0].collages.count() == 0:
-            self.workspaces[USER_WORKSPACES][0].collages.create()
-
-        if changes:
-            self.save_workspaces()
-        return self.workspaces
-
-    def _in_collection(self, workspace):
-        """Check if given workspace is already in current collection.
-        """
-        for group, workspaces in self.workspaces.items():
-            if workspace in workspaces:
-                return True
-        return False
-
-    def add_other(self, workspace_id):
-        """
-        Add a workspace in "other",
-
-        if the workspace is not already in your collection.
-
-        Sometimes you want to add workspaces from others
-        """
-        workspace = Workspace.objects.get(pk=workspace_id)
-        if not self._in_collection(workspace):
-            if OTHER_WORKSPACES not in self.workspaces:
-                self.workspaces[OTHER_WORKSPACES] = []
-            self.workspaces[OTHER_WORKSPACES].append(workspace)
-
-
 class WorkspaceItemAdapter(object):
     """Base class for workspace_item adapters.
 
@@ -176,12 +44,19 @@ class WorkspaceItemAdapter(object):
     is_animatable = False
     allow_custom_legend = False
 
-    def __init__(self, workspace_item, layer_arguments=None):
-        self.workspace_item = workspace_item
+    def __init__(self, workspace_item, layer_arguments=None,
+                 adapter_class=None):
+        self.workspace_mixin_item = workspace_item
+        self.workspace_item = workspace_item  # For backwards compatibility
+
         if layer_arguments is not None:
             self.layer_arguments = layer_arguments
         else:
             self.layer_arguments = {}
+        self.adapter_class = adapter_class
+
+        # All arguments, for passing through
+        self.layer_arguments = layer_arguments
 
     def layer(self, layer_ids=None, request=None):
         """Generates and returns layers, styles.
@@ -410,83 +285,64 @@ class WorkspaceItemAdapter(object):
         return 'html output for this adapter is not implemented'
 
     def html_default(self, snippet_group=None, identifiers=None,
-                     layout_options=None, template=None,
-                     extra_render_kwargs=None):
+                     layout_options=None,
+                     template=None, extra_render_kwargs=None):
         """
-        Returns html representation of given snippet_group OR
-        identifiers (snippet_group has priority). If a snippet_group
-        is provided, more options are available. Only snippets with
-        attribute visible=True are included in the result.
+        Default implementation for html view ("popup"). It returns an
+        html snippet with links in it.
 
-        This particular view always renders a list of items, then 1
-        image.
+        Not all kwargs are still used, but they exist for backwards
+        compatibility.
 
         Use this function if html function behaviour is default:
         def html(self, identifiers):
             return super(WorkspaceItemAdapterKrw, self).html_default(
                 identifiers)
         """
-
-        if layout_options is None:
-            layout_options = {}
-        add_snippet = layout_options.get('add_snippet', False)
-        editing = layout_options.get('editing', False)
-        legend = layout_options.get('legend', False)
-
-        if snippet_group is not None:
-            snippets = snippet_group.snippets.filter(visible=True)
-            identifiers = [snippet.identifier for snippet in snippets]
-            title = str(snippet_group)
-        else:
-            snippets = []
-            title = self.workspace_item.name
-
-        # Image url: for snippet_group there is a special (dynamic) url.
-        if snippet_group:
-            # Image url for snippet_group: can change if snippet_group
-            # properties are altered.
-            img_url = reverse(
-                "lizard_map.snippet_group_image",
-                kwargs={'snippet_group_id': snippet_group.id},
-                )
-        else:
-            # Image url: static url composed with all options and layout tweaks
-            img_url = reverse(
-                "lizard_map.workspace_item_image",
-                kwargs={'workspace_item_id': self.workspace_item.id},
-                )
-            # If legend option: add legend to layout of identifiers
-            if legend:
-                for identifier in identifiers:
-                    if not 'layout' in identifier:
-                        identifier['layout'] = {}
-                    identifier['layout']['legend'] = True
-
-            identifiers_escaped = [json.dumps(identifier).replace('"', '%22')
-                                   for identifier in identifiers]
-            img_url = img_url + '?' + '&'.join(['identifier=%s' % i for i in
-                                                identifiers_escaped])
-
-        # Make 'display_group'
-        display_group = [self.location(**identifier) for identifier in
-                         identifiers]
-
         if template is None:
-            template = 'lizard_map/popup.html'
+            template = 'lizard_map/html_default.html'
+
+        is_collage = False
+        if layout_options is not None:
+            if 'is_collage' in layout_options:
+                is_collage = layout_options['is_collage']
+
+        # Fetch name
+        if identifiers:
+            location = self.location(**identifiers[0])
+            title = location['name']
+            if len(identifiers) > 1:
+                title += ' + ...'
+        else:
+            title = self.workspace_mixin_item.name
+
+        # Build "adapter-image" url for current adapter and identifiers.
+        img_url = self.workspace_mixin_item.url(
+            "lizard_map_adapter_image", identifiers)
+
+        # Makes it possible to create collage items from current
+        # selected objects.
+        collage_item_props = []
+        for identifier in identifiers:
+            location = self.location(**identifier)
+            collage_item_props.append(
+                {'name': location['name'],
+                 'adapter_class': self.workspace_mixin_item.adapter_class,
+                 'adapter_layer_json':
+                     self.workspace_mixin_item.adapter_layer_json,
+                 'identifier': adapter_serialize(identifier),
+                 'url': self.workspace_mixin_item.url(
+                        "lizard_map_adapter_values", [identifier, ],
+                        extra_kwargs={'output_type': 'csv'})})
+
         render_kwargs = {
             'title': title,
-            'display_group': display_group,
             'img_url': img_url,
             'symbol_url': self.symbol_url(),
-            'add_snippet': add_snippet,
-            'editing': editing,
-            'snippet_group': snippet_group,
-            'snippets': snippets,
-            'colors': COLORS_DEFAULT,
-            }
-
-        if extra_render_kwargs is not None:
-            render_kwargs.update(extra_render_kwargs)
+            'collage_item_props': collage_item_props,
+            'is_collage': is_collage}
+        if layout_options is not None:
+            render_kwargs.update(layout_options)
 
         return render_to_string(
             template,
